( function( $ ) {
	"use strict";
	
	/**
	 * Sliding Messages
	 * 
	 * @package slidingmessages
	 * @since 3.0
	 * @author appscreo
	 */
	var slidingMessages = { 'debug_mode': false };
	
	var debounce = function( func, wait ) {
		var timeout, args, context, timestamp;
		return function() {
			context = this;
			args = [].slice.call( arguments, 0 );
			timestamp = new Date();
			var later = function() {
				var last = ( new Date() ) - timestamp;
				if ( last < wait ) {
					timeout = setTimeout( later, wait - last );
				} else {
					timeout = null;
					func.apply( context, args );
				}
			};
			if ( ! timeout ) {
				timeout = setTimeout( later, wait );
			}
		};
	};
	
	var isElementInViewport = function (el) {

	    //special bonus for those using jQuery
	    if (typeof jQuery === "function" && el instanceof jQuery) {
	        el = el[0];
	    }

	    var rect = el.getBoundingClientRect();

	    return (
	        rect.top >= 0 &&
	        rect.left >= 0 &&
	        rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) && /*or $(window).height() */
	        rect.right <= (window.innerWidth || document.documentElement.clientWidth) /*or $(window).width() */
	    );
	};


	slidingMessages.setCookie = function(cname, cvalue, exdays) {
	    var d = new Date();	    
		d.setTime(d.getTime() + (exdays * 1000));
	    
	    var expires = "expires="+d.toGMTString();
	    
	    
	    if (!slidingMessages.debug_mode)
	    	document.cookie = cname + "=" + cvalue + "; " + expires + "; path=/";
	    else
	    	console.log('sending cookie = ' + cname+ ' = ' + cvalue +', expires = ' + expires);
	}
	
	slidingMessages.getCookie = function(cname) {
	    var name = cname + "=";
	    var decodedCookie = decodeURIComponent(document.cookie);
	    
	    var ca = decodedCookie.split(';');
	    for(var i = 0; i <ca.length; i++) {
	        var c = ca[i];
	        while (c.charAt(0) == ' ') {
	            c = c.substring(1);
	        }
	        if (c.indexOf(name) == 0) {
	            return c.substring(name.length, c.length);
	        }
	    }
	    return "";
	}
	
	slidingMessages.sendDeactivationCookie = function(id) {
		// no deactivation cookie is running
		
		if (slidingMessages.debug_mode) console.log('sendDeactivationCookie start for = ' + id);
		
		if (slidingmarketing['on_hide'] == '') return;
		
		if (slidingmarketing['on_hide'] == 'page') {
			if (slidingMessages.debug_mode) console.log('id set on hide page ' + id);
			slidingMessages.setCookie('sm3-'+id+'-'+slidingmarketing['post_id'], 'true', slidingmarketing['reshow_after_setup']);
		}

		if (slidingmarketing['on_hide'] == 'all') {
			if (slidingMessages.debug_mode) console.log('id set on hide all ' + id);
			slidingMessages.setCookie('sm3-'+id+'-all', 'true', slidingmarketing['reshow_after_setup']);
		}
	}
	
	slidingMessages.deactivatedFromCookie = function(id) {
		var cookie_current = slidingMessages.getCookie('sm3-'+id+'-'+slidingmarketing['post_id']),
			r = false;
		
		if (cookie_current == 'true')
			r = true;
		else {
			cookie_current = slidingMessages.getCookie('sm3-'+id+'-all');
			
			if (cookie_current == 'true')
				r = true;
		}
		
		return r;
	}
	
	slidingMessages.hide = function(element_id) {
		if ($('#' + element_id).length) 
			$('#' + element_id).removeClass('slidingmessage-active');
		
		if (slidingMessages.messages[element_id] && slidingMessages.messages[element_id].reopen) {
			var reopen_id = "slidingmessage-open-" + slidingMessages.messages[element_id].id;
			
			if ($('#' + reopen_id).length) 
				$('#' + reopen_id).addClass('slidingmessage-active');
		}
		
		if (slidingMessages.messages[element_id] && slidingMessages.messages[element_id].forcehide) {
			var id = slidingMessages.messages[element_id].id;
			console.log('id set on hide force all ' + id);
			var expiration = 2629746;
			if (Number(slidingMessages.messages[element_id].forcehide_days) && Number(slidingMessages.messages[element_id].forcehide_days) != 0)
				expiration = slidingMessages.messages[element_id].forcehide_days * 86400;
			slidingMessages.setCookie('sm3-'+id+'-all', 'true', expiration.toString());

		}
			
	}
	
	slidingMessages.show = function(element_id, forceShow) {
		
		if (!forceShow) {
			if (slidingMessages.messages[element_id].displayed) return;
			if (slidingMessages.deactivatedFromCookie(slidingMessages.messages[element_id].id)) return;
		}
		
		if ($('#' + element_id).length) {
			$('#' + element_id).addClass('slidingmessage-active');
			
			slidingMessages.messages[element_id].displayed = true;
			
			if (slidingMessages.debug_mode) {
				console.log('show = ' + element_id);
				console.log(slidingMessages.messages[element_id]);
			}
			
			if (!slidingMessages.messages[element_id].nocookies) {
				if (slidingMessages.debug_mode) {
					console.log('beforeSendDecativationCookie = ' + element_id + ', id = ' + slidingMessages.messages[element_id].id);
				}
				slidingMessages.sendDeactivationCookie(slidingMessages.messages[element_id].id);
			}
			
			if (slidingMessages.messages[element_id] && Number(slidingMessages.messages[element_id].disappear_at)) {
				var disappear = Number(slidingMessages.messages[element_id].disappear_at) * 1000;
				
				setTimeout(function(){
					if (slidingMessages.debug_mode)
						console.log('timeout event disappear = ' + element_id+', time = ' + disappear);
					slidingMessages.hide(element_id); 
					}, disappear);
			}
		}
	}
	
	slidingMessages.close = function(id) {
		var element_id = 'slidingmessage-' + id;
		slidingMessages.hide(element_id);
	}
	
	slidingMessages.subscribe = function(key, event) {
		event.preventDefault();
		
		var formContainer = $('.sm-subscribe-' + key + ' .sm-subscribeform');
		if (formContainer.length) {
			var user_mail = $(formContainer).find('.sm-subscribe-email').val();
			var user_name = '';
			$(formContainer).find('.sm-subscribe-submit').prop('disabled', true);
			$(formContainer).hide();
			$('.sm-subscribe-' + key).find('.sm-subscribe-loader').show();
			var submitapi_call = formContainer.attr('action') + '&mailchimp_email='+user_mail+'&mailchimp_name='+user_name;
				
			$.post(submitapi_call, { mailchimp_email1: user_mail, mailchimp_name1: user_name}, 
					function (data) {

						if (data) {
						
							if (slidingMessages.debug_mode)
								console.log(data);
						
						if (data['code'] == '1') {
							$('.sm-subscribe-' + key).find('.sm-subscribe-form-content-success').show();
							$('.sm-subscribe-' + key).find('.sm-subscribe-form-content-error').hide();		
							$(formContainer).hide();
							
						}
						else {
							var storedMessage = $('.sm-subscribe-' + key).find('.sm-subscribe-form-content-error').attr('data-message') || '';
							if (storedMessage == '') {
								 $('.sm-subscribe-' + key).find('.sm-subscribe-form-content-error').attr('data-message', $('.essb-subscribe-form-' + key).find('.essb-subscribe-form-content-error').text());
							}
							
							if (data['code'] == 90)
								$('.sm-subscribe-' + key).find('.sm-subscribe-form-content-error').text(data['message']);
							else
								$('.sm-subscribe-' + key).find('.sm-subscribe-form-content-error').text(storedMessage);
							$('.sm-subscribe-' + key).find('.sm-subscribe-form-content-error').show();						
							$('.sm-subscribe-' + key).find('.sm-subscribeform').show();	
							$(formContainer).find('.sm-subscribe-submit').prop('disabled', false);
						}
						$('.sm-subscribe-' + key).find('.sm-subscribe-loader').hide();
					}},
			'json');

		}
	}

	
	window.slidingMessages = slidingMessages;
	
	$(document).ready(function(){

		slidingMessages.messages = {};
		slidingMessages.hasScrollEvent = false;
		slidingMessages.hasElementWatch = false;

		var mobileBreakPoint = 800;
		if (slidingmarketing['hide_mobile_resolution'] && Number(slidingmarketing['hide_mobile_resolution']))
			mobileBreakPoint = Number(slidingmarketing['hide_mobile_resolution']);
		
		$('.slidingmessage').each(function(){
			
			
			// mobile resolution - do not run 
			if (slidingmarketing['hide_mobile'] && $(window).width() < mobileBreakPoint) 
				return;
			
			var appear = $(this).attr('data-appear') || 'time',
				appear_at = $(this).attr('data-appear-at') || '',
				disappear_at = $(this).attr('data-disappear') || '',
				reopen = $(this).attr('data-reopen') || '',
				message_id = $(this).attr('data-id') || '',
				forcehide = $(this).attr('data-forcehide') || '',
				forcehide_days = $(this).attr('data-forcehide-days') || '',
				element_id = $(this).id || '',
				nocookie = $(this).attr('data-nocookie') || '';
			
			if (slidingMessages.debug_mode)
				console.log('element_id = ' + element_id+', appear = ' + appear);
			
			if ($(this).width() > $(window).width())
				$(this).width($(window).width());
			
			if (slidingMessages.debug_mode) 
				console.log($(this).find('.sm-content').outerHeight() + ' - ' + $( window ).height());
			
			if ($(this).find('.sm-content').length) {
				if ($(this).find('.sm-content').outerHeight() > $( window ).height() ) {
					
					if (slidingMessages.debug_mode) 
						console.log('fixing height');
					
					$(this).find('.sm-content').css("overflow", "hidden");
					$(this).find('.sm-content').css("overflowY", "scroll");
					$(this).find('.sm-content').css("height", "100%");
				}
			}
			
			
			if (element_id == '' && message_id != '') element_id = 'slidingmessage-' + message_id;
			
			if (element_id == '') return;
			
			slidingMessages.messages[element_id] = {
					'appear': appear,
					'appear_at': appear_at,
					'disappear_at': disappear_at,
					'reopen': reopen,
					'id': message_id,
					'forcehide': (forcehide == '1' ? true : false),
					'forcehide_days': Number(forcehide_days) ? Number(forcehide_days) : 0,
					'element': $(this),
					'element_id': element_id,
					'displayed': false,
					'nocookies': (nocookie == '1' ? true: false)
			}
			
			if (appear == 'scroll')
				slidingMessages.hasScrollEvent = true;
			if (appear == 'element')
				slidingMessages.hasElementWatch = true;
			
			if (appear == 'time') {
				if (!Number(appear_at)) appear_at = 100; else appear_at = Number(appear_at) * 1000;
				
				setTimeout(function(){
					
					if (slidingMessages.debug_mode)
						console.log('timeout event = ' + element_id+', time = ' + appear_at);
					
					slidingMessages.show(element_id); 
					}, appear_at);
			}
			
			if ($(this).find('.sm-close a').length) {
				$(this).find('.sm-close a').on('click', function(e){
					e.preventDefault();
					
					var message_id = $(this).attr('data-close');
					
					if (slidingMessages.debug_mode)
						console.log('closing message_id ' + message_id);
					if (message_id != '') slidingMessages.hide(message_id);
				});
			}
			
			// corect top center position
			if ($(this).hasClass('sm-position-left') || $(this).hasClass('sm-position-right')) {
				 var h = $(this).innerHeight();
				 $(this).css('top', '50%');
			     $(this).css('margin-top', Math.floor(h / 2) * -1);
			}
			
			if ($(this).hasClass('sm-position-center')) {
				 var h = $(this).innerHeight();
				 var w = $(this).innerWidth();
				 $(this).css('top', '50%');
			     $(this).css('margin-top', Math.floor(h / 2) * -1);
				 $(this).css('left', '50%');
			     $(this).css('margin-left', Math.floor(w / 2) * -1);
			}
			
			if ($(this).hasClass('sm-position-full')) {
				var h = $(this).find('.sm-content').innerHeight();				
				$(this).find('.sm-content').css('height', h);
			}
			
		});
		
		$('.sm-manual-close').each(function(){
			$(this).on('click', function(e) {
				e.preventDefault();
				
				if ($(this).closest(".slidingmessage").length) {
					var message_id = $(this).closest(".slidingmessage").attr('data-id') || '',
						element_id = $(this).closest(".slidingmessage").id || '';
					
					if (element_id == '' && message_id != '') element_id = 'slidingmessage-' + message_id;
					
					if (element_id == '') return;
					
					slidingMessages.hide(element_id);
				}
			});
		});
		
		$('.slidingmessage-open').each(function(){
			$(this).on('click', function(e) {
				e.preventDefault();
				
				var message_id = $(this).attr('data-id') || '',
					element_id = '';
			
			
				if (element_id == '' && message_id != '') element_id = 'slidingmessage-' + message_id;
			
				if (element_id == '') return;
			
				slidingMessages.show(element_id, true);
			
			});
			
			if ($(this).hasClass('sm-position-left') || $(this).hasClass('sm-position-right') ||
					$(this).hasClass('sm-position-left-sidebar') || $(this).hasClass('sm-position-right-sidebar')) {
				 var h = $(this).innerHeight();
				 $(this).css('top', '50%');
			     $(this).css('margin-top', Math.floor(h / 2) * -1);
			}
			
			if ($(this).hasClass('sm-position-center')) {
				 var h = $(this).innerHeight();
				 var w = $(this).innerWidth();
				 $(this).css('top', '50%');
			     $(this).css('margin-top', Math.floor(h / 2) * -1);
				 $(this).css('left', '0');
			}
			
			if ($(this).hasClass('sm-position-topbar') || $(this).hasClass('sm-position-bottombar')) {
				 var h = $(this).innerWidth();
				 $(this).css('left', '50%');
			     $(this).css('margin-left', Math.floor(h / 2) * -1);
			}
		});
		
		
		var slidingMessagesScrollEvent = function() {

			var current_pos = $(window).scrollTop();
			var height = $(document).height() - $(window).height();
			var percentage = current_pos / height * 100;
			
			for (var element_id in slidingMessages.messages) {
				if (slidingMessages.messages[element_id].displayed) continue;
				if (slidingMessages.messages[element_id].appear != 'scroll') continue;
				
				var checkValue = Number(slidingMessages.messages[element_id].appear_at) || 1;
				
				if (checkValue <= percentage) {
					if (slidingMessages.debug_mode)
						console.log('scroll trigger on ' + percentage+', value = ' + checkValue)
					slidingMessages.show(element_id);
				}
			}
		}
		
		if (slidingMessages.hasScrollEvent)
			$(window).scroll(debounce(slidingMessagesScrollEvent, 1));
		
		var slidingMessagesElementWatchEvent = function() {

			var current_pos = $(window).scrollTop();
			var height = $(document).height() - $(window).height();
			var percentage = current_pos / height * 100;
			
			for (var element_id in slidingMessages.messages) {
				if (slidingMessages.messages[element_id].displayed) continue;
				if (slidingMessages.messages[element_id].appear != 'element') continue;
				
				var elementSelector = slidingMessages.messages[element_id].appear_at;
				
				if (!document.querySelector(elementSelector)) continue;
				
				if (isElementInViewport(document.querySelector(elementSelector))) {
					if (slidingMessages.debug_mode)
						console.log('scroll trigger on selector value = ' + elementSelector)
						
					slidingMessages.show(element_id);
				}
			}
		}
		
		if (slidingMessages.hasElementWatch)
			$(window).scroll(slidingMessagesElementWatchEvent);

		
		// countdown timer
		 function getTimeRemaining(endtime) {
			    var t = Date.parse(endtime) - Date.parse(new Date());
			    var seconds = Math.floor((t / 1000) % 60);
			    var minutes = Math.floor((t / 1000 / 60) % 60);
			    var hours = Math.floor((t / (1000 * 60 * 60)) % 24);
			    var days = Math.floor(t / (1000 * 60 * 60 * 24));
			    return {
			      'total': t,
			      'days': days,
			      'hours': hours,
			      'minutes': minutes,
			      'seconds': seconds
			    };
			  }
			  
			  function initializeClock(endtime){
			  var timeinterval = setInterval(function(){
			    var t = getTimeRemaining(endtime);
			    document.querySelector(".days > .value").innerText=t.days;
			    document.querySelector(".hours > .value").innerText=t.hours;
			    document.querySelector(".minutes > .value").innerText=t.minutes;
			    document.querySelector(".seconds > .value").innerText=t.seconds;
			    if(t.total<=0){
			      clearInterval(timeinterval);
			    }
			  },1000);
			  }
			  
		 if ($('.sm-countdown').length) {
			 var timer_interval = $('.sm-countdown').attr('data-timer') || '';
			 
			 if (timer_interval)
				 initializeClock(timer_interval);
		 }
	});
	

} )( jQuery );

