<?php
class SlidingMarketingAdmin {
	
	function __construct() {
		add_action ( 'widgets_init', array ($this, 'register_sidebar' ) );
		
		if (is_admin()) {
			add_action ( 'admin_enqueue_scripts', array ($this, 'register_admin_assets' ), 99 );
			add_action ( 'admin_init', array ($this, 'register_settings' ) );
			$hook = (defined ( 'WP_NETWORK_ADMIN' ) && WP_NETWORK_ADMIN) ? 'network_admin_menu' : 'admin_menu';
			add_action ( $hook, array ($this, 'create_admin_menu_entry' ) );
			
			add_filter("manage_edit-" . SLIDINGMESSAGES_POSTTYPE . "_columns", array($this, "add_custom_columns"));
			add_action("manage_posts_custom_column",  array($this, "fill_custom_columns"));
		}
	}
	
	function add_custom_columns ($cols) {
		return array_merge($cols, array(
				'slidingmessages_message_type' => esc_html__('Content Type', 'slidingmarketing'),
				'sm_status' => esc_html__('Status', 'slidingmarketing'),
		));
	}
	
	function fill_custom_columns ($col) {
		global $post;
		if ('slidingmessages_message_type' != $col && 'sm_status' != $col) return $col;
		
		if ($col == 'slidingmessages_message_type') {
			$message_content_parts = slidingmarketing_message_settings($post, 'message-type');
			
			if (in_array('text', $message_content_parts)) {
				echo esc_html__('Free text/html content', 'slidingmarketing').'<br/>';
			}
			if (in_array('sidebar', $message_content_parts)) {
				echo esc_html__('Sidebar', 'slidingmarketing').'<br/>';
			}
			if (in_array('related', $message_content_parts)) {
				echo esc_html__('Related Posts', 'slidingmarketing').'<br/>';
			}
			if (in_array('optin', $message_content_parts)) {
				echo esc_html__('Subscribe Form', 'slidingmarketing').'<br/>';
			}				
		}
		
		if ($col == 'sm_status') {
			$is_paused = get_post_meta($post->ID, 'sm-paused', true);
			$post_manual_status = get_post_meta($post->ID, 'sm-manual-assign', true);
			$always_displayed = get_post_meta($post->ID, 'sm-always-displayed', true);

			$nocookies = get_post_meta($post->ID, 'sm-nocookies', true);
			
			$fromdate = get_post_meta($post->ID, 'sm-fromdate', true);
			$todate = get_post_meta($post->ID, 'sm-todate', true);
				
				
			$type_limit = get_post_meta($post->ID, 'sm-post-types');
			$cat_limit = get_post_meta($post->ID, 'sm-categories');
				
			echo esc_html__('Paused: ', 'slidingmarketing').($is_paused ? 'YES' : 'NO').'<br/>';
			echo esc_html__('Manual Display: ', 'slidingmarketing').($post_manual_status ? 'YES' : 'NO').'<br/>';
			echo esc_html__('Always Display: ', 'slidingmarketing').($always_displayed ? 'YES' : 'NO').'<br/>';

			if ($nocookies) {
				echo esc_html__('Don\'t Apply On Close Rules: ', 'slidingmarketing').($nocookies ? 'YES' : 'NO').'<br/>';
			}
			
			if ($fromdate != '' || $todate != '') {
				echo esc_html__('Period: ', 'slidingmarketing').$fromdate.' - ' .$todate.'<br/>';
			}
			
			if ($type_limit) {
				echo esc_html__('For the following types: ', 'slidingmarketing').implode(', ', $type_limit).'<br/>';
			}
			
			if ($cat_limit) {
				echo esc_html__('Selected categories: ', 'slidingmarketing').implode(', ', $cat_limit).'<br/>';
			}
				
		}
	}
	
	function register_admin_assets() {
		global $post;
		$is_valid = isset ( $_GET ['page'] ) && 'slidingmarketing' == $_GET ['page'];
		
		if (!$is_valid) {
			$is_valid = (is_object ( $post ) && isset ( $post->post_type ) && SLIDINGMESSAGES_POSTTYPE == $post->post_type);
		}
		
		if ($is_valid) {
			wp_enqueue_style ( 'sm-admin', SLIDINGMESSAGES_PLUGIN_URL . '/assets/css/sm-admin.css' );
			wp_enqueue_script ( 'sm-admin', SLIDINGMESSAGES_PLUGIN_URL . '/assets/js/sm-admin.js', array ('jquery' ), SLIDINGMESSAGES_VERSION );
			
		}
	}
	
	function register_settings() {
	
		register_setting ( 'slidingmarketing', 'slidingmarketing' );
	}
	
	function create_admin_menu_entry() {
		if (@$_POST && isset ( $_POST ['option_page'] )) {
			$changed = false;
			if ('slidingmarketing' == slidingmarketing_options_value ( $_POST, 'option_page' )) {
				update_option ( 'slidingmarketing', $_POST ['sm'] );
				$changed = true;
			}
				
			if ($changed) {
				$goback = add_query_arg ( 'settings-updated', 'true', wp_get_referer () );
				wp_redirect ( $goback );
				die ();
			}
		}
		$page = "edit.php?post_type=" . SLIDINGMESSAGES_POSTTYPE;
		$perms = is_multisite () ? 'manage_network_options' : 'manage_options';
		add_submenu_page ( $page, esc_html__( 'Settings', 'slidingmarketing' ), esc_html__( 'Settings', 'slidingmarketing' ), $perms, 'slidingmarketing', array ($this, 'plugin_settings' ) );
	}
	
	function plugin_settings() {
		include (SLIDINGMESSAGES_PLUGIN_BASE_DIR . '/includes/plugin-settings.php');
	}
	
	function register_sidebar() {
		if (! slidingmarketing_get_option ( 'allow_widgets' ))
			return false;
		
		$widget_count = slidingmarketing_get_option ( 'allow_widgets_count' );
		if (! $widget_count) {
			$widget_count = '1';
		}
		
		$widget_count = intval ( $widget_count );
		
		for($i = 1; $i <= $widget_count; $i ++) {
			register_sidebar ( array ('name' => esc_html__( 'Sliding Marketing ' . $i, 'slidingmarketing' ), 'id' => 'slidingmarketing-' . $i, 'description' => esc_html__( 'This sidebar can be used as a Sliding Marketing Message content.', 'slidingmarketing' ), 'class' => '', 'before_widget' => '<aside id="%1$s" class="sm-widget sm-slide-col %2$s">', 'after_widget' => '</aside>', 'before_title' => '<h3 class="sm-widget_title widget_title">', 'after_title' => '</h3>' ) );
		
		}
	}
}